@@ -1,6 +1,6 @@
 from .crosswalk import Crosswalk
 from .resolve import Resolve
 from .table import Table
-from .contribute import Contribute
+from .submit import Submit
 from .facets import Facets
 from .flag import Flag
